package Peace::Test::Mock::Model::Developer;

use v5.30.1;

use strict;
use warnings;

use DBI;

use Peace::Model::Developer;

sub new {
    my $class = shift; 
    return Peace::Model::Developer->new(
        name => 'Larry',
        surname => 'Wall',
        secret_bcrypt => 'hola',
        email => 'larry@perl.org',
        country => 'US',
        verified => 0,
        dbh => DBI->connect('dbi:Mock:'),
    );
}
1;
=encoding utf8

=head1 NAME

Peace::Test::Mock::Model::Developer - Mock object for Peace::Model::Developer.

=head1 SYNOPSIS

 my $developer = Peace::Test::Mock::Model::Developer->new;

=head1 DESCRIPTION

Peace::Test::Mock::Model::Developer aims to reduce repeated code which
doesn't bring new things to tests by avoiding to add long lines
in order to create a L<Peace::Model::Developer> object on a
unrelated test by providing a stub one already created object.

=head1 INSTANCE METHODS

Peace::Test::Mock::Model::Developer implements the following instance
methods:

=head2 new

 my $developer = Peace::Test::Mock::Model::Developer->new;

Returns a mock L<Peace::Model::Developer> object.


=head1 SEE ALSO

L<Peace::Model::Developer>
